Retrieves a list of registered models.
mlflow_list_registered_models(
max_results = 100,
page_token = NULL,
client = NULL
)Maximum number of registered models to retrieve.
Pagination token to go to the next page based on a previous query.
(Optional) An MLflow client object returned from mlflow_client. If specified, MLflow will use the tracking server associated with the passed-in client. If unspecified (the common case), MLflow will use the tracking server associated with the current tracking URI.